@@ -304,6 +304,8 @@ class Bot:
             pass
         elif pl.opcode == api.opcode.reconnect or pl.opcode == api.opcode.session_invalidated:
             self.reconnect = True
+            if pl.opcode == api.opcode.session_invalidated:
+                self.session_id = None
         else:
             self.log("Unknown payload received: %s" % pl, severity = log_severity.warning)
     
